%global ibus_api_version 1.0
%global pkgcache /var/cache/%name
%global __python %{__python3}

%bcond_without    gtk4

%global gtk3_binary_version %(pkg-config  --variable=gtk_binary_version gtk+-3.0)

%if %{with gtk4}
%global gtk4_binary_version %(pkg-config  --variable=gtk_binary_version gtk4)
%endif

%global glib_ver %([ -a %{_libdir}/pkgconfig/glib-2.0.pc ] && pkg-config --modversion glib-2.0 | cut -d. -f 1,2 || echo -n "999")


Summary:        Intelligent Input Bus for Linux OS
Name:           ibus
Version:        1.5.28
Release:        6%{?dist}
License:        LGPL-2.0-or-later
URL:            https://github.com/%{name}/%{name}/wiki
Source0:        https://github.com/%{name}/%{name}/releases/download/%{version}/%{name}-%{version}.tar.gz
Source1:        %{name}-xinput
Patch3000:      %{name}-HEAD.patch
Patch3001:      %{name}-1385349-segv-bus-proxy.patch

BuildRequires:  libtool git pkg-config
BuildRequires:  glib2-doc gettext-devel gtk-doc unicode-ucd
BuildRequires:  gtk3-devel
%if %{with gtk4}
BuildRequires:  gtk4-devel
%endif
BuildRequires:  dbus-glib-devel dbus-python-devel dbus-x11 systemd systemd-devel
BuildRequires:  desktop-file-utils
BuildRequires:  libXtst-devel dconf-devel
BuildRequires:  python3-devel python3-gobject vala
BuildRequires:  iso-codes-devel libnotify-devel wayland-devel

Requires:       %{name}-libs   = %{version}-%{release}
Requires:       %{name}-gtk3   = %{version}-%{release}
Requires:       %{name}-setup  = %{version}-%{release}

Requires:       iso-codes
Requires:       dconf
Requires:       python3-gobject
%{?__python3:Requires: %{__python3}}
Requires:       xorg-x11-xinit
Requires:       setxkbmap

Requires:               desktop-file-utils
Requires(post):         desktop-file-utils
Requires(postun):       desktop-file-utils
Requires:               dconf
Requires(postun):       dconf
Requires(posttrans):    dconf

Requires:               %{_sbindir}/alternatives
Requires(post):         %{_sbindir}/alternatives
Requires(postun):       %{_sbindir}/alternatives

%global _xinputconf %{_sysconfdir}/X11/xinit/xinput.d/ibus.conf

%description
IBus is an Intelligent Input Bus. It is a new input framework for Linux OS.
It provides full featured and user friendly input method user interface.
It also may help developers to develop input method easily.

%package libs
Summary:        IBus libraries
Requires:       dbus >= 1.2.4
Requires:       glib2 >= %{glib_ver}
Requires:       gobject-introspection

%description libs
This package provides the libraries for IBus

%package gtk3
Summary:        IBus IM module for GTK3
Requires:       %{name}-libs   = %{version}-%{release}
Requires:       glib2 >= %{glib_ver}
Requires(post): glib2 >= %{glib_ver}

%description gtk3
This package contains IBus IM module for GTK3

%if %{with gtk4}
%package gtk4
Summary:        IBus IM module for GTK4
Requires:       %{name}-libs   = %{version}-%{release}
Requires:       glib2 >= %{glib_ver}
Requires(post): glib2 >= %{glib_ver}

%description gtk4
This package contains IBus IM module for GTK4
%endif

%package setup
Summary:        IBus setup utility
Requires:       %{name} = %{version}-%{release}
%{?__python3:Requires: %{__python3}}
Requires:       python3-gobject
BuildRequires:  gobject-introspection-devel
BuildRequires:  pygobject3-devel
BuildRequires:  make
BuildArch:      noarch

%description setup
This package provides a setup utility for IBus.

%package wayland
Summary:        IBus IM module for Wayland
Requires:       %{name}-libs   = %{version}-%{release}

%description wayland
This package contains IBus IM module for Wayland

%package devel
Summary:        Development tools for ibus
Requires:       %{name}-libs   = %{version}-%{release}
Requires:       dbus-devel
Requires:       glib2-devel
Requires:       gettext-runtime

%description devel
The ibus-devel package contains the header files and developer
docs for ibus.


%prep
%autosetup -S git



%build
autoreconf -fiv
%configure \
    --disable-static \
    --disable-gtk2 \
    --enable-gtk3 \
%if %{with gtk4}
    --enable-gtk4 \
%endif
    --enable-xim \
    --disable-gtk-doc \
    --enable-surrounding-text \
    --with-python=python3 \
    --disable-python2 \
    --enable-wayland \
    --enable-introspection \
    --disable-emoji-dict \
    --disable-install-tests

make -C ui/gtk3 maintainer-clean-generic
%make_build

%install
make install DESTDIR=%{buildroot} INSTALL='install -p'
rm -f %{buildroot}%{_libdir}/libibus-*%{ibus_api_version}.la
rm -f %{buildroot}%{_libdir}/gtk-3.0/%{gtk3_binary_version}/immodules/im-ibus.la
%if %{with gtk4}
rm -f %{buildroot}%{_libdir}/gtk-4.0/%{gtk4_binary_version}/immodules/libim-ibus.la
%endif
rm -rf %{buildroot}%{_datadir}/gtk-doc/html

install -pm644 -D %{SOURCE1} %{buildroot}%{_xinputconf}
install -m755 -d %{buildroot}%pkgcache/bus

echo "NoDisplay=true" >> %{buildroot}%{_datadir}/applications/org.freedesktop.IBus.Setup.desktop

HAS_PREFIX=$(grep prefix %{buildroot}%{_bindir}/ibus-setup | wc -l)
[ x"$HAS_PREFIX" == x1 ] && \
  sed -i -e '/prefix/d' %{buildroot}%{_bindir}/ibus-setup

desktop-file-install --delete-original          \
  --dir %{buildroot}%{_datadir}/applications \
  %{buildroot}%{_datadir}/applications/*

%find_lang %{name}10

%check
make check \
    DISABLE_GUI_TESTS="ibus-compose ibus-keypress test-stress xkb-latin-layouts" \
    VERBOSE=1

%post
%{_sbindir}/alternatives --install %{_sysconfdir}/X11/xinit/xinputrc xinputrc %{_xinputconf} 83 || :

%postun
if [ "$1" -eq 0 ]; then
  %{_sbindir}/alternatives --remove xinputrc %{_xinputconf} || :
  [ -L %{_sysconfdir}/alternatives/xinputrc -a "`readlink %{_sysconfdir}/alternatives/xinputrc`" = "%{_xinputconf}" ] && %{_sbindir}/alternatives --auto xinputrc || :

  dconf update || :
  [ -f %{_sysconfdir}/dconf/db/ibus ] && \
      rm %{_sysconfdir}/dconf/db/ibus || :
fi

%posttrans
dconf update || :

%transfiletriggerin -- %{_datadir}/ibus/component
[ -x %{_bindir}/ibus ] && \
  %{_bindir}/ibus write-cache --system &>/dev/null || :

%transfiletriggerpostun -- %{_datadir}/ibus/component
[ -x %{_bindir}/ibus ] && \
  %{_bindir}/ibus write-cache --system &>/dev/null || :



%files -f %{name}10.lang
%license COPYING
%doc AUTHORS README
%{_bindir}/ibus
%{_bindir}/ibus-daemon
%{_datadir}/bash-completion/completions/ibus.bash
%{_datadir}/dbus-1/services/*.service
%{_datadir}/GConf/gsettings/*
%{_datadir}/glib-2.0/schemas/*.xml
%{_datadir}/ibus/component
%{_datadir}/ibus/dicts
%dir %{_datadir}/ibus/
%dir %{_datadir}/ibus/engine
%{_datadir}/ibus/keymaps
%{_datadir}/icons/hicolor/*/apps/*
%{_datadir}/man/man1/ibus.1.gz
%{_datadir}/man/man1/ibus-daemon.1.gz
%{_datadir}/man/man5/00-upstream-settings.5.gz
%{_datadir}/man/man5/ibus.5.gz
%{_libexecdir}/ibus-engine-simple
%{_libexecdir}/ibus-dconf
%{_libexecdir}/ibus-portal
%{_libexecdir}/ibus-ui-gtk3
%{_libexecdir}/ibus-x11
%{_sysconfdir}/dconf/db/ibus.d
%{_sysconfdir}/dconf/profile/ibus
%dir %{_sysconfdir}/xdg/Xwayland-session.d
%{_sysconfdir}/xdg/Xwayland-session.d/10-ibus-x11
%{_prefix}/lib/systemd/user/gnome-session.target.wants/*.service
%{_prefix}/lib/systemd/user/org.freedesktop.IBus.session.*.service
%python3_sitearch/gi/overrides/__pycache__/*.py*
%python3_sitearch/gi/overrides/IBus.py
%dir %{_sysconfdir}/X11/xinit/xinput.d
%config %{_xinputconf}
%verify(not mtime) %dir %pkgcache
%verify(not mtime) %dir %pkgcache/bus
%ghost %pkgcache/bus/registry

%files libs
%{_libdir}/libibus-*%{ibus_api_version}.so.*
%dir %{_libdir}/girepository-1.0
%{_libdir}/girepository-1.0/IBus*-1.0.typelib

%files gtk3
%{_libdir}/gtk-3.0/%{gtk3_binary_version}/immodules/im-ibus.so

%if %{with gtk4}
%files gtk4
%{_libdir}/gtk-4.0/%{gtk4_binary_version}/immodules/libim-ibus.so
%endif

%files setup
%{_bindir}/ibus-setup
%{_datadir}/ibus/setup
%{_datadir}/man/man1/ibus-setup.1.gz
%{_datadir}/applications/org.freedesktop.IBus.Setup.desktop

%files wayland
%{_libexecdir}/ibus-wayland

%files devel
%{_libdir}/lib*.so
%{_libdir}/pkgconfig/*
%{_includedir}/*
%{_datadir}/gettext/its/ibus.*
%dir %{_datadir}/gir-1.0
%{_datadir}/gir-1.0/IBus*-1.0.gir
%dir %{_datadir}/vala
%dir %{_datadir}/vala/vapi
%{_datadir}/vala/vapi/ibus-*1.0.vapi
%{_datadir}/vala/vapi/ibus-*1.0.deps

%changelog
* Thu Sep 26 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 1.5.28-6
- Rebuilt for clarifying the packages requirement in BaseOS and AppStream

* Tue Sep 24 2024 cunshunxia <cunshunxia@tencent.com> - 1.5.28-5
- add systemd-devel buildrequire which contains pkgconf file.

* Fri Aug 16 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 1.5.28-4
- Rebuilt for loongarch release

* Tue Sep 19 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 1.5.28-3
- Rebuilt for python 3.11

* Fri Sep 08 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 1.5.28-2
- Rebuilt for OpenCloudOS Stream 23.09

* Wed Aug 16 2023 Shuo Wang <abushwang@tencent.com> - 1.5.28-1
- update to 1.5.28

* Fri Apr 28 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 1.5.27-4
- Rebuilt for OpenCloudOS Stream 23.05

* Fri Mar 31 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 1.5.27-3
- Rebuilt for OpenCloudOS Stream 23

* Thu Feb 23 2023 cunshunxia <cunshunxia@tencent.com> - 1.5.27-2
- enable gtk4.

* Wed Nov 23 2022 cunshunxia <cunshunxia@tencent.com> - 1.5.27-1
- initial build
